@@ -1,4 +1,4 @@
-from typing import Union, Optional
+from typing import Dict, Union, Optional
 from uuid import UUID
 
 from airflow import AirflowException
@@ -28,6 +28,7 @@ class SimpleCircuitBreakerOperator(BaseMcdOperator):
                  rule_name: Optional[str] = None,
                  timeout_in_minutes: Optional[int] = 5,
                  fail_open: Optional[bool] = True,
+                 runtime_variables: Optional[Dict[str, str]] = None,
                  *args, **kwargs):
         """
         Operator for Circuit breaking rules (custom SQL monitors) with MCD.
@@ -48,6 +49,7 @@ class SimpleCircuitBreakerOperator(BaseMcdOperator):
         filtering down the query output to improve performance (e.g limit WHERE clause). If you expect a query to
         take the full 15 minutes we recommend padding the timeout to 20 minutes.
         :param fail_open: Prevent any errors or timeouts when executing a rule from stopping your pipeline.
+        :param runtime_variables: Runtime variables to pass to the rule.
         Raises AirflowSkipException if set to True.
         """
         retry_handler = dict(retries=OP_RETRIES) if OP_RETRIES is not None else {}
@@ -58,6 +60,7 @@ class SimpleCircuitBreakerOperator(BaseMcdOperator):
         self.rule_name = rule_name
         self.timeout_in_minutes = timeout_in_minutes
         self.fail_open = fail_open
+        self.runtime_variables = runtime_variables
 
     def execute(self, *args, **kwargs) -> None:
         """
@@ -65,8 +68,11 @@ class SimpleCircuitBreakerOperator(BaseMcdOperator):
         """
         service = CircuitBreakerService(mc_client=Client(self.get_session()), print_func=self.log.info)
         try:
-            in_breach = service.trigger_and_poll(rule_uuid=self.rule_uuid, namespace=self.namespace,
-                                                 rule_name=self.rule_name, timeout_in_minutes=self.timeout_in_minutes)
+            in_breach = service.trigger_and_poll(rule_uuid=self.rule_uuid,
+                                                 namespace=self.namespace,
+                                                 rule_name=self.rule_name,
+                                                 timeout_in_minutes=self.timeout_in_minutes,
+                                                 runtime_variables=self.runtime_variables)
         except Exception as err:
             if not self.fail_open:
                 raise AirflowException from err
